========
Overview
========

NBAWebStats is a Python interface to the stats.nba.com HTTP API, compatible with
Python 3.3-3.5.

NBAWebStats was developed from existing packages for the same purpose such as
py-goldsberry_, without which NBAWebStats would not be possible. Compared to
py-goldsberry, NBAWebStats offers the following attributes:

.. _py-goldsberry: http://github.com/bradleyfay/py-Goldsberry

* Interface adherent to :pep:`8`.
* Smaller, more maintainable code footprint due to reduced boilerplate (single
  ~200 line python file vs 10 files totalling ~2350 lines).
* Centralized documentation of permitted request types and parameters online_.
* Descriptive package name.
* Support for Python 3 (but not for Python 2).

.. _online: http://nbawebstats.readthedocs.org/en/master/requests.html

Details
-------

* Source repository: http://github.com/agirardeaudale/nbawebstats
* Documentation: https://nbawebstats.readthedocs.org.
* Free software: MIT license
